/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.fleet.implement.tree;

import java.util.List;
import javax.swing.Action;
import nl.cloudfarming.client.fleet.implement.wizard.ImplementWizardAction;
import nl.cloudfarming.client.fleet.machine.tree.MachineCategoryChildFactory;
import nl.cloudfarming.client.fleet.machine.tree.MachineCategoryNode;
import nl.cloudfarming.client.fleet.model.ImplementService;
import nl.cloudfarming.client.fleet.model.Machine;
import nl.cloudfarming.client.fleet.model.MachineService;
import org.netbeans.api.project.Project;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.util.lookup.Lookups;

/**
 *
 * @author Wytse Visser
 */
public class ImplementCategoryNode extends MachineCategoryNode {

    private Project project;
    
    public ImplementCategoryNode(Project project, MachineCategoryChildFactory childFactory) {
        super(childFactory, Lookups.fixed(new ImplementCategoryInfo()));

        this.project = project;
        setDisplayName(getMetaInfo().getDisplayName());
        setIconBaseWithExtension(getMetaInfo().getSmallIconResource());
    }

    @Override
    public List<Machine> getMachines() {
        MachineService service = Lookup.getDefault().lookup(ImplementService.class);
        return service.getMachines(project);
    }

    @Override
    public Action[] getActions(boolean context) {
        return new Action[]{
                    new OpenAction(),
                    null,
                    new ImplementWizardAction(project),
                };
    }

    @NbBundle.Messages("displayName=Implements")
    public static class ImplementCategoryInfo implements MachineMetaInfo {

        private final String ICON_SMALL = "nl/cloudfarming/client/fleet/implement/implement.png";
        private final String ICON_LARGE = "nl/cloudfarming/client/fleet/implement/implement32.png";

        @Override
        public String getDisplayName() {
            return Bundle.displayName();
        }

        @Override
        public String getSmallIconResource() {
            return ICON_SMALL;
        }

        @Override
        public String getLargeIconResource() {
            return ICON_LARGE;
        }
    }
}